==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/eo.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Rondoj",
    "Circles' files" : "Dosieroj de la rondoj",
    "Select circles to filter by" : "Elekti rondojn per kiu filtri",
    "No circles found" : "Neniu rondo trovita",
    "Please select circles to filter by" : "Nv. elekti rondojn per kiu filtri",
    "No files found for the selected circles" : "Neniu dosiero trovita kun la elektitaj rondoj",
    "You created the circle {circle}" : "Vi kreis la rondon {circle}",
    "{author} created the circle {circle}" : "{author} kreis la rondon {circle}",
    "You deleted {circle}" : "Vi forigis la rondon {circle}",
    "{author} deleted {circle}" : "{author} forigis la rondon {circle}",
    "You linked {group} to {circle}" : "Vi ligis grupon {group} al rondo {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} estis ligita al rondo {circle} de {author}",
    "You unlinked {group} from {circle}" : "Vi malligis grupon {group} el rondo {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} estis malligita el rondo {circle} de {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Vi ŝanĝis la nivelon de la ligita grupo {group} en rondo {circle} al %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ŝanĝis la nivelon de la ligita grupo {group} en rondo {circle} al %1$s",
    "You sent a request to link {circle} with {remote}" : "Vi sendis peton por ligi rondon {circle} kun {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} sendis peton por ligi rondon {circle} kun {remote}",
    "{remote} requested a link with {circle}" : "{remote} petis ligilon kun rondo {circle}",
    "The request to link {circle} with {remote} has been rejected" : "La peto ligi rondon {circle} kun {remote} estis malakceptita",
    "The request to link {remote} with {circle} has been canceled remotely" : "La peto ligi rondon {circle} kun {remote} estis fore nuligita",
    "The request to link {circle} with {remote} has been accepted" : "La peto ligi rondon {circle} kun {remote} estis akceptita",
    "You dismissed the request to link {remote} with {circle}" : "Vi rifuzis peton por ligi {remote} kun rondo {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} rifuzis peton por ligi {remote} kun rondo {circle}",
    "You canceled the request to link {circle} with {remote}" : "Vi nuligis peton por ligi rondon {circle} kun {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} nuligis peton por ligi rondon {circle} kun {remote}",
    "You accepted the request to link {remote} with {circle}" : "Vi akceptis peton por ligi {remote} kun rondo {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} akceptis peton por ligi {remote} kun rondo {circle}",
    "A link between {circle} and {remote} is now up and running" : "Ligilo inter {circle} kaj {remote} estas unu funkcianta",
    "The link between {circle} and {remote} has been shutdown remotely" : "La ligilo inter {circle} kaj {remote} estis fore fermita",
    "You closed the link between {circle} and {remote}" : "Vi fermis la ligilon inter {circle} kaj {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} fermis la ligilon inter {circle} kaj {remote}",
    "You joined {circle}" : "Vi membriĝis al {circle}",
    "{member} joined {circle}" : "{member} membriĝis al {circle}",
    "You accepted the invitation to join {circle}" : "Vi akceptis inviton membriĝi al {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} akceptis inviton membriĝi al {circle}",
    "You added {member} as member to {circle}" : "Vi aldonis {member} kiel membron de {circle}",
    "You have been added as member to {circle} by {author}" : "{author} aldonis vin kiel membron de {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} aldonis {member} kiel membron de {circle}",
    "You added {external} to {circle}" : "Vi aldonis {external} al {circle}",
    "{external} has been added to {circle} by {author}" : "{author} aldonis membron {external} al {circle}",
    "You accepted {member}'s request to join {circle}" : "Vi akceptis peton de {member} por membriĝi al {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} akceptis vian peton por membriĝi al {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} akceptis peton de {member} por membriĝi al {circle}",
    "You left {circle}" : "Vi forlasis rondon {circle}",
    "{member} left {circle}" : "{member} forlasis rondon {circle}",
    "You declined the invitation to join {circle}" : "Vi rifuzis inviton membriĝi al {circle}",
    "{member} declined an invitation to join {circle}" : "{member} rifuzis inviton membriĝi al {circle}",
    "You cancelled your request to join {circle}" : "Vi nuligis peton por membriĝi al {circle}",
    "{member} cancelled his request to join {circle}" : "{member} nuligis sian peton por membriĝi al {circle}",
    "You removed {member} from {circle}" : "Vi forigis {member} el {circle}",
    "You have been removed from {circle} by {author}" : "{author} forigis vin el {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} forigis membron {member} el {circle}",
    "You removed {external} from {circle}" : "Vi forigis {external} el {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} forigis {external} el {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Vi nuligis inviton de {member} membriĝi al {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} nuligis vian inviton membriĝi al {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} nuligis inviton de {member} membriĝi al {circle}",
    "You dismissed {member}'s request to join {circle}" : "Vi rifuzis peton de {member} membriĝi al {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Via peto membriĝi al {circle} estis rifuzita de {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Peto de {member} membriĝi al {circle} estis rifuzita de {author}",
    "You invited {member} to join {circle}" : "Vi invitis {member} membriĝi al {circle}",
    "You have been invited to join {circle} by {author}" : "{author} invitis vin membriĝi al {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} invitis membron {member} membriĝi al {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Vi ŝanĝis nivelon de {member} en {circle} al %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ŝanĝis vian nivelon en {circle} al %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ŝanĝis nivelon de {member} en {circle} al %1$s",
    "You sent a request to join {circle}" : "Vi sendis peton por membriĝi al {circle}",
    "{member} sent a request to join {circle}" : "{member} sendis peton por membriĝi al {circle}",
    "You are the new owner of {circle}" : "Vi nun estas la nova posedanto de {circle}",
    "{member} is the new owner of {circle}" : "{member} nun estas la nova posedanto de {circle}",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Pri grava evento en <strong>rondo</strong> kiun vi kontrolas",
    "Shared to Circles" : "Kunhavigita kun rondoj",
    "Personal" : "Persona",
    "Contact" : "Kontakto",
    "Circle" : "Rondo",
    "Member" : "Membro",
    "Moderator" : "Kontrolanto",
    "Admin" : "Administranto",
    "Owner" : "Posedanto",
    "%s shared »%s« with you." : "%s kunhavigis „%s“ kun vi.",
    "%s on %s" : "%s el %s",
    "%1$s via %2$s" : "%1$s pere de %2$s",
    "Click the button below to open it." : "Alklaku la butonon ĉi-sube por malfermi ĝin.",
    "Open »%s«" : "Malfermi „%s“",
    "Circle not found" : "Rondo ne trovita",
    "A circle with that name exists" : "Rondo kun sama nomo jam ekzistas",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Vi ne povas uzi la aplikaĵon „Rondoj“, ĝis via administranto permesas almenaŭ unu tipon de rondoj.",
    "This member does not exist" : "Tiu ĉi membro ne ekzistas",
    "This user is already a member of the circle" : "Tiu ĉi uzanto jam estas membro el tiu rondo",
    "Federated link not found" : "Federa ligilo ne trovita",
    "This feature is not available for personal circles" : "Tiu funkcio ne disponeblas por persona rondo",
    "The circle is not federated" : "La rondo ne estas federita",
    "You cannot join this circle" : "Vi ne povas membriĝi al tiu ĉi rondo",
    "This member is not a moderator" : "Tiu ĉi membro ne estas kontrolanto",
    "Insufficient privileges" : "Nesufiĉaj rajtoj",
    "This member is the owner of the circle" : "Tiu ĉi membro estas la posedanto de tiu ĉi rondo",
    "Level cannot be changed for this type of member" : "Nivelo ne ŝanĝeblas por tiu tipo de membro",
    "You are already a member of this circle" : "Vi jam estas membro de tiu ĉi rondo",
    "You have been blocked from this circle" : "Vi estis barita el tiu ĉi rondo",
    "The user is already a member of this circle" : "La uzanto jam estas membro de tiu ĉi rondo",
    "The user has already been invited into this circle" : "La uzanto jam estis invitita al tiu ĉi rondo",
    "Accept" : "Akcepti",
    "You need a specify a type of circle" : "Vi bezonas indiki tipon de rondo",
    "This member is not the owner of the circle" : "Tiu ĉi membro ne estas la posedanto de la rondo",
    "This member is not an admin of the circle" : "Tiu ĉi membro ne estas administranto el la rondo",
    "This group does not exist" : "Tiu ci grupo ne ekzistas",
    "This group is already linked to the circle" : "Tiu ĉi grupo jam estas ligita al la rondo",
    "You cannot edit level in a personal circle" : "Vi ne povas modifi nivelon en persona rondo",
    "Group cannot be set as owner of a circle" : "Grupo ne povas esti posedanto de rondo",
    "now" : "nun",
    "This user does not exist" : "Tiu ĉi uzanto ne ekzistas",
    "Email format is not valid" : "Formo de retpoŝtadreso ne validas",
    "This contact is not available" : "Tiu kontakto ne disponeblas",
    "Could not find share" : "Ne eblis trovi kunhavon",
    "Bring cloud-users closer together." : "Pliproksimigi uzantojn kune.",
    "No files in here" : "Neniu dosiero ĉi tie",
    "No entries found in this folder" : "Neniu elemento en tiu ĉi dosierujo",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "Maximum number of members per circle" : "Po maksimuma nombro da membroj por rondo",
    "Allow linking of groups" : "Permesi interligi grupojn",
    "Groups can be linked to circles." : "Grupoj ligeblas al rondoj.",
    "Skip invitation step to closed circles" : "Preterpasi la etapon pri invito al fermitaj rondoj",
    "Moderators can add member to closed circles without user approval." : "Kontrolantoj povas aldoni membrojn en malfermitaj rondoj sen uzant-aprobo.",
    "Are you sure you want to transfer your ownership?" : "Ĉu vi certas pri la transigo de via posedaĵo?",
    "This action is irreversible" : "Tiu ago estas nenuligebla",
    "Personal circle" : "Persona rondo",
    "Secret circle" : "Sekreta rondo",
    "Closed circle" : "Fermita rondo",
    "Public circle" : "Publika rondo",
    "Link Removed" : "Ligilo forigita",
    "Link down" : "Ligilo nefunkcianta",
    "Setting link" : "Estiganta ligilo",
    "Request dismissed" : "Peto malakceptita",
    "Request sent" : "Peto sendita",
    "Link requested" : "Ligilo petita",
    "Link up" : "Ligilo aktivita",
    "Personal Circle" : "Persona rondo",
    "Secret Circle" : "Sekreta rondo",
    "Closed Circle" : "Fermita rondo",
    "Public Circle" : "Publika rondo",
    "Secret" : "Sekreta",
    "Closed" : "Fermita",
    "Public" : "Publika",
    "Not a member" : "Nemembro",
    "Unknown" : "Nekonata",
    "Invited" : "Invitita",
    "Requesting" : "Petado",
    "Blocked" : "Barita",
    "Kicked" : "Forpelita",
    "This operation will add/invite all members of the group to the circle" : "Tio operacio aldonos aŭ invitos ĉiujn membrojn el la grupo al la rondo",
    "Please confirm" : "Bv. konfirmi",
    "Are you sure you want to leave this circle?" : "Ĉu vi certas, ke vi volas forlasi tiun rondon?",
    "Are you sure you want to delete this circle?" : "Ĉu vi certas, ke vi volas forigi tiun rondon?",
    "Mail Address" : "Retpoŝtadreso",
    "Kick this member" : "Forpeli tiun membron",
    "Accept the request" : "Akcepti peton",
    "Dismiss the request" : "Ignori peton",
    "Unlink this group" : "Malligi tiun grupon",
    "Remove this link" : "Forigi tiun ligilon",
    "Cancel the link request" : "Nuligi peton de ligilo",
    "Accept the link request" : "Akcepti peton de ligilo",
    "Reject the link request" : "Rifuzi peton de ligilo",
    "Cannot join this circle" : "Ne eblas membriĝi al tiu rondo",
    "no error message" : "Neniu erarmesaĝo",
    "You have joined this circle" : "Vi membriĝis al tiu rondo",
    "You have requested to join this circle" : "Vi petis membriĝon al tiu rondo",
    "You have left this circle" : "Vi forlasis tiun rondon",
    "Cannot leave this circle" : "Ne eblas forlasi tiun rondon",
    "You have deleted this circle" : "Vi forigis tiun rondon",
    "Cannot delete this circle" : "Ne eblas forigi tiun rondon",
    " {type} '{name}' created" : " {type} „{name}“ kreita",
    " {type} '{name}' could not be created" : " {type} „{name}“ ne eblis kreiĝi",
    "Issue while retrieving the details of this circle" : "Problemo dum ricevo de detaloj pri tiu rondo",
    "Issue while retrieving the list of circles" : "Problemo dum ricevo de la listo de rondoj",
    "Group '{name}' successfully added to the circle" : "Grupo „{name}“ sukcese aldonita al la rondo",
    "Group '{name}' could not be added to the circle" : "Grupo „{name}“ malsukcesis esti aldonita al la rondo",
    "Group '{name}' updated" : "Grupo „{name}“ ĝisdatigita",
    "Group '{name}' could not be updated" : "Grupo „{name}“ ne eblis esti ĝisdatigita",
    "Group '{name}' successfully removed from the circle" : "Grupo „{name}“ sukcese forigita el la rondo",
    "Group '{name}' could not be removed from the circle" : "Grupo „{name}“ malsukcese forigita el la rondo",
    "A link to <b>{remote}</b> could not be initiated" : "Ligilo al <b>{remote}</b> ne eblis ekkomenci",
    "A link to <b>{remote}</b> has been requested." : "Ligilo al <b>{remote}</b> petita",
    "the link to <b>{remote}</b> is now up and running." : "ligilo al <b>{remote}</b> estas nun funkcianta.",
    "The status of the link could not be updated" : "La stato de la ligilo ne eblis esti ĝisdatigita",
    "The status of the link has been updated" : "La stato de la ligilo estis ĝisdatigita",
    "Local User" : "Loka uzanto",
    "Local Group" : "Loka grupo",
    "The email address '{email}' was added to the circle" : "La retpoŝtadreso „{email}“ aldoniĝis al la rondo",
    "The email address '{email}' could not be added to the circle" : "La retpoŝtadreso „{email}“ ne eblis esti aldonita al la rondo",
    "Members of the group '{name}' were added to the circle" : "Membroj el la grupo „{name}“ aldoniĝis al la rondo",
    "Members of the group '{name}' could not be added to the circle" : "Membroj el la grupo „{name}“ ne eblis esti aldonita al la rondo",
    "Members of the group '{name}' were invited to the circle" : "Membroj el la grupo „{name}“ estis invititaj al la rondo",
    "Members of the group '{name}' could not be invited to the circle" : "Membroj el la grupo „{name}“ ne eblis esti invititaj al la rondo",
    "Issue while saving settings" : "Problemo dum konservado de agordoj",
    "Settings saved." : "Agordoj konservitaj",
    "%s shared »%s« with '%s'." : "%s kunhavigis „%s“ kun „%s“.",
    "The name of your circle must contain at least 3 characters" : "La rondonomo enhavu almenaŭ 3 signojn",
    "Linked Groups are not allowed on this Nextcloud" : "Ligitaj grupoj ne estas permesataj en tiu ĉi Nextcloud",
    "Federated circles are not allowed on this Nextcloud" : "Federaj rondoj ne estas permesataj en tiu ĉi Nextcloud",
    "Sharing Frame does not exist" : "Kunhaviga kadro ne ekzistas",
    "You cannot create this type of circle" : "Vi ne povas krei tiun ĉi tipon de rondo",
    "You cannot display this type of circle" : "Vi ne povas montri tiun ĉi tipon de rondo",
    "Federated link does not have a valid format" : "Federa ligilo ne havas validan formon",
    "Federated circles are not allowed on the remote Nextcloud" : "Federajn rondojn ne permesas la fora Nextcloud",
    "Remote circle does not accept federated links" : "Fora rondo ne akceptas federajn ligilojn",
    "Trying to link a circle to itself" : "Provo ligi rondon al ĝi mem",
    "This link exists already" : "Tiu ĉi ligilo jam ekzistas",
    "The requested remote circle does not exist" : "La petita fora rondo ne ekzistas",
    "The remote host is down or the Circles app is not installed on it" : "La fora gasto ne funkcias aŭ la aplikaĵo „Rondoj“ ne estas instalita ĉe ĝi",
    "Cannot proceed with this status update" : "Ne eblas plui kun tiu stata ĝisdatigo",
    "Create a new circle" : "Krei novan rondon",
    "Select a circle type" : "Elekti rondotipon",
    "Create a personal circle" : "Krei personan rondon",
    "Create a public circle" : "Krei publikan rondon",
    "Create a closed circle" : "Krei fermitan rondon",
    "Create a secret circle" : "Krei sekretan rondon",
    "Creation" : "Kreado",
    "A personal circle is a list of users known only to the owner." : "Person rondo estas listo de uzantoj konita nur de la posedanto.",
    "This is the right option if you want to do recurrent sharing with the same list of local users." : "Estas la bona elekto, se vi volas kutime komuniki kun la sama listo de lokaj uzantoj.",
    "A secret circle is an hidden group that can only be seen by its members or by people knowing the exact name of the circle." : "Sekreta rondo estas kaŝita grupo, kiu nur estas videbla de siaj membro aŭ de personoj, kiuj konas ekzakte la nomon de la rondo.",
    "Non-members won't be able to find your secret circle using the search bar." : "Nemembroj ne eblos trovi la sekretan rondon per la serĉilo.",
    "Joining a closed circle requires an invitation or confirmation by a moderator." : "Membriĝi al fermita rondo postulas inviton aŭ konfirmon fare de kontrolanto.",
    "A public circle is an open group visible to anyone willing to join." : "Publika rondo estas malferma grupo videbla de ĉiuj, kiuj volas membriĝi.",
    "Anyone can see, join, and access the items shared within the circle." : "Ĉiu povas vidi, membriĝi kaj aliri la elementojn kunhavigitajn ene de la rondo.",
    "Personal circles" : "Personaj rondoj",
    "Public circles" : "Publikaj rondoj",
    "Closed circles" : "Fermitaj rondoj",
    "Secret circles" : "Sekretaj rondoj",
    "All circles" : "Ĉiuj rondoj",
    "Search circles" : "Serĉi rondojn",
    "No filter" : "Neniu filtrilo",
    "Circles you belong to" : "Rondoj, de kiuj vi estas membro",
    "Circles you own" : "Rondoj, kiujn vi posedas",
    "No circle selected" : "Neniu rondo elektita",
    "Settings" : "Agordoj",
    "Pending invitation to join this circle" : "Pritraktota invito al membriĝo de tiu rondo",
    "You have a pending request to join this circle" : "Vi havas pritraktotan peton por membriĝi al tiu rondo",
    "Add a member" : "Aldoni membron",
    "Link a group" : "Ligi grupon",
    "Link a circle" : "Ligi rondon",
    "Join this circle" : "Membriĝi al tiu ĉi rondo",
    "Delete circle" : "Forigi rondon",
    "Edit circle" : "Modifi rondon",
    "Accept the invitation" : "Akcepti la inviton",
    "Decline the invitation" : "Malakcepti la inviton",
    "Leave this circle" : "Forlasi tiun ĉi rondon",
    "Link to a circle" : "Ligilo al rondo",
    "Return to menu" : "Antaŭen al menuo",
    "Username" : "Uzantnomo",
    "Level" : "Nivelo",
    "Status" : "Stato",
    "Joined" : "Membriĝinta",
    "Group Name" : "Grupnomo",
    "Link" : "Ligilo",
    "Linked" : "Ligita",
    "Description" : "Priskribo",
    "Members limit" : "Maksimuma nombro da membroj",
    "Change the limit to the number of members. (0: default, -1: unlimited)" : "Ŝanĝi limon pri nombro da membroj (0: defaŭlta; -1: senlima).",
    "Change password" : "Ŝanĝi la pasvorton",
    "Allow Federated Links" : "Permesi federaj ligiloj",
    "Makes the circle federated, and enables sharing between federated circles" : "Federigas la rondon, kaj ebligas kunhavigojn inter federaj rondoj",
    "Accept Link Request Automatically" : "Akcepti ligilo-peton aŭtomate",
    "Warning: Enabling this will automatically accept new link requests from other circles." : "Averto: novaj ligilo-petoj estos akceptitaj aŭtomate el aliaj rondoj, se vi ebligas tiun opcion.",
    "Save settings" : "Konservi agordojn"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/eo.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Vi forigis la rondon {circle}",
    "{author} deleted {circle}" : "{author} forigis la rondon {circle}",
    "You joined {circle}" : "Vi membriĝis al {circle}",
    "{member} joined {circle}" : "{member} membriĝis al {circle}",
    "You accepted the invitation to join {circle}" : "Vi akceptis inviton membriĝi al {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} akceptis inviton membriĝi al {circle}",
    "You added {member} as member to {circle}" : "Vi aldonis {member} kiel membron de {circle}",
    "You have been added as member to {circle} by {author}" : "{author} aldonis vin kiel membron de {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} aldonis {member} kiel membron de {circle}",
    "You added {external} to {circle}" : "Vi aldonis {external} al {circle}",
    "{external} has been added to {circle} by {author}" : "{author} aldonis membron {external} al {circle}",
    "You accepted {member}'s request to join {circle}" : "Vi akceptis peton de {member} por membriĝi al {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} akceptis vian peton por membriĝi al {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} akceptis peton de {member} por membriĝi al {circle}",
    "You left {circle}" : "Vi forlasis rondon {circle}",
    "{member} left {circle}" : "{member} forlasis rondon {circle}",
    "You declined the invitation to join {circle}" : "Vi rifuzis inviton membriĝi al {circle}",
    "{member} declined an invitation to join {circle}" : "{member} rifuzis inviton membriĝi al {circle}",
    "You cancelled your request to join {circle}" : "Vi nuligis peton por membriĝi al {circle}",
    "You removed {member} from {circle}" : "Vi forigis {member} el {circle}",
    "You have been removed from {circle} by {author}" : "{author} forigis vin el {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} forigis membron {member} el {circle}",
    "You removed {external} from {circle}" : "Vi forigis {external} el {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} forigis {external} el {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Vi nuligis inviton de {member} membriĝi al {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} nuligis vian inviton membriĝi al {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} nuligis inviton de {member} membriĝi al {circle}",
    "You dismissed {member}'s request to join {circle}" : "Vi rifuzis peton de {member} membriĝi al {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Via peto membriĝi al {circle} estis rifuzita de {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Peto de {member} membriĝi al {circle} estis rifuzita de {author}",
    "You invited {member} to join {circle}" : "Vi invitis {member} membriĝi al {circle}",
    "You have been invited to join {circle} by {author}" : "{author} invitis vin membriĝi al {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} invitis membron {member} membriĝi al {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Vi ŝanĝis nivelon de {member} en {circle} al %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ŝanĝis vian nivelon en {circle} al %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ŝanĝis nivelon de {member} en {circle} al %1$s",
    "You sent a request to join {circle}" : "Vi sendis peton por membriĝi al {circle}",
    "{member} sent a request to join {circle}" : "{member} sendis peton por membriĝi al {circle}",
    "You are the new owner of {circle}" : "Vi nun estas la nova posedanto de {circle}",
    "{member} is the new owner of {circle}" : "{member} nun estas la nova posedanto de {circle}",
    "Shared to Circles" : "Kunhavigita kun rondoj",
    "Personal" : "Persona",
    "System" : "Sistemo",
    "Visible" : "Videbla",
    "Open" : "Malfermi",
    "Password protected" : "Protektita per pasvorto",
    "Hidden" : "Nevidebla",
    "Local" : "Loka",
    "Root" : "Radiko",
    "Federated" : "Federated",
    "Email address" : "Retpoŝtadreso",
    "Contact" : "Kontakto",
    "Circle" : "Rondo",
    "Member" : "Membro",
    "Moderator" : "Kontrolanto",
    "Admin" : "Administranto",
    "Owner" : "Posedanto",
    "%s shared »%s« with you." : "%s kunhavigis „%s“ kun vi.",
    "%s on %s" : "%s el %s",
    "%1$s via %2$s" : "%1$s pere de %2$s",
    "Click the button below to open it." : "Alklaku la butonon ĉi-sube por malfermi ĝin.",
    "Open »%s«" : "Malfermi „%s“",
    "This feature is not available for personal circles" : "Tiu funkcio ne disponeblas por persona rondo",
    "This member is not a moderator" : "Tiu ĉi membro ne estas kontrolanto",
    "Insufficient privileges" : "Nesufiĉaj rajtoj",
    "This member does not exist" : "Tiu ĉi membro ne ekzistas",
    "Level cannot be changed for this type of member" : "Nivelo ne ŝanĝeblas por tiu tipo de membro",
    "You are already a member of this circle" : "Vi jam estas membro de tiu ĉi rondo",
    "You have been blocked from this circle" : "Vi estis barita el tiu ĉi rondo",
    "Accept" : "Akcepti",
    "%s" : "%s",
    "Bring cloud-users closer together." : "Pliproksimigi uzantojn kune.",
    "No files in here" : "Neniu dosiero ĉi tie",
    "No entries found in this folder" : "Neniu elemento en tiu ĉi dosierujo",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "Circles" : "Rondoj",
    "Circles' files" : "Dosieroj de la rondoj",
    "Select circles to filter by" : "Elekti rondojn per kiu filtri",
    "No circles found" : "Neniu rondo trovita",
    "Please select circles to filter by" : "Nv. elekti rondojn per kiu filtri",
    "No files found for the selected circles" : "Neniu dosiero trovita kun la elektitaj rondoj",
    "You created the circle {circle}" : "Vi kreis la rondon {circle}",
    "{author} created the circle {circle}" : "{author} kreis la rondon {circle}",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Pri grava evento en <strong>rondo</strong> kiun vi kontrolas",
    "Circle not found" : "Rondo ne trovita",
    "Federated link not found" : "Federa ligilo ne trovita",
    "The circle is not federated" : "La rondo ne estas federita",
    "You cannot join this circle" : "Vi ne povas membriĝi al tiu ĉi rondo",
    "This member is the owner of the circle" : "Tiu ĉi membro estas la posedanto de tiu ĉi rondo",
    "Personal Circle" : "Persona rondo",
    "You need a specify a type of circle" : "Vi bezonas indiki tipon de rondo",
    "A circle with that name exists" : "Rondo kun sama nomo jam ekzistas",
    "This member is not the owner of the circle" : "Tiu ĉi membro ne estas la posedanto de la rondo",
    "This member is not an admin of the circle" : "Tiu ĉi membro ne estas administranto el la rondo",
    "This group does not exist" : "Tiu ci grupo ne ekzistas",
    "This group is already linked to the circle" : "Tiu ĉi grupo jam estas ligita al la rondo",
    "You cannot edit level in a personal circle" : "Vi ne povas modifi nivelon en persona rondo",
    "Group cannot be set as owner of a circle" : "Grupo ne povas esti posedanto de rondo",
    "now" : "nun",
    "Email format is not valid" : "Formo de retpoŝtadreso ne validas",
    "This contact is not available" : "Tiu kontakto ne disponeblas"
},
"nplurals=2; plural=(n != 1);");
